@@ -1,13 +1,11 @@
 from __future__ import annotations
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 
-from typing_extensions import Literal
-
-from .color_util import AnsiMode, LightDark
 from .constants import CONFIG_PATH
 from .neofetch_util import ColorAlignment
 from .serializer import json_stringify, from_dict
+from .types import AnsiMode, LightDark, BackendLiteral
 
 
 @dataclass
@@ -16,7 +14,8 @@ class Config:
     mode: AnsiMode
     light_dark: LightDark = 'dark'
     lightness: float | None = None
-    color_align: ColorAlignment = ColorAlignment('horizontal')
+    color_align: ColorAlignment = field(default_factory=lambda: ColorAlignment('horizontal'))
+    backend: BackendLiteral = "neofetch"
 
     @classmethod
     def from_dict(cls, d: dict):
